@@ -51,8 +51,6 @@ def spatial_diffusion_values(
         # ----------------
         # plot real values to check for outliers
         # ----------------
-        #from energy_demand.plotting import plotting_program
-        #plotting_program.plot_xy(list(real_values.values()))
 
         # Select number of outliers to remove lower and higher extremes
         nr_of_outliers = int(100 / len(regions) * p_outlier)
@@ -70,9 +68,6 @@ def spatial_diffusion_values(
             if val < treshold_lower_real_value:
                 real_values[reg] = treshold_lower_real_value
 
-        # Plot after removing outliers
-        #plotting_program.plot_xy(list(real_values.values()))
-
         # ---------------------------------
         # Congruence calculations
         # ----------------------------------
@@ -103,18 +98,6 @@ def spatial_diffusion_values(
 
             diffusion_values[region] = lower_concept_val + higher_concept_val
 
-            '''logging.info(
-                "Reg: %s diffusion_value: %s real_value: %s",
-                region,
-                lower_concept_val + higher_concept_val,
-                real_value)'''
-        '''min_val = max(diffusion_values.values())
-        for i in diffusion_values:
-            if diffusion_values[i] == min_val:
-                min_reg = i
-        import logging
-        logging.info("print  {}  {}  ".format(min_reg, min_val))
-        '''
     return diffusion_values
 
 def calc_diffusion_f(regions, f_reg, spatial_diff_values, fuels):
@@ -592,11 +575,10 @@ def factor_improvements_single(
     # Replace
     reg_enduse_tech_p_ey = reg_enduse_tech_p_ey_capped
 
-    logging.warning("FAKTOR UK :" + str(factor_uk))
-    logging.warning("Lost demand: " + str(demand_lost))
-    logging.warning("TESTDUM a " + str(test))
-    logging.warning("TESTDUM b " + str(uk_enduse_fuel * factor_uk))
-
+    #logging.warning("FAKTOR UK :" + str(factor_uk))
+    #logging.warning("Lost demand: " + str(demand_lost))
+    #logging.warning("TESTDUM a " + str(test))
+    #logging.warning("TESTDUM b " + str(uk_enduse_fuel * factor_uk))
     return reg_enduse_tech_p_ey
 
 def get_enduse_regs(
