@@ -28,7 +28,6 @@ def energy_demand_model(
         data,
         criterias,
         assumptions,
-        weather_stations,
         weather_yr,
         weather_by
     ):
@@ -65,7 +64,6 @@ def energy_demand_model(
         data=data,
         criterias=criterias,
         assumptions=assumptions,
-        weather_stations=weather_stations,
         weather_yr=weather_yr,
         weather_by=weather_by)
 
@@ -85,7 +83,7 @@ if __name__ == "__main__":
     if os.path.isfile(sys.argv[1]):
         path_config  = sys.argv[1]
     else:
-        raise Exception("The defined .ini file does not exist_ {}".format(sys.argv[1]))
+        raise Exception("The defined .ini file does not exist: {}".format(sys.argv[1]))
     config = data_loader.read_config_file(path_config)
 
     data = {}
@@ -116,19 +114,21 @@ if __name__ == "__main__":
     if config['CRITERIA']['cluster_calc']:
         path_weather_data = "/soge-home/staff/cenv0553/_weather_realisation"
     else:
-        path_weather_data = "C:/Users/cenv0553/ED/data/scenarios"
+        path_weather_data = "C:/Users/cenv0553/nismod2/data/energy_demand/scenarios"
 
-    if name_config_path == 'h_max' or name_config_path == 'l_max' or name_config_path in ['test_run', 'h_max_0', 'h_max_10', 'h_max_0_only', 'h_max_10_only']:
+    '''if name_config_path == 'h_max' or name_config_path == 'l_max' or name_config_path in ['test_run', 'h_max_0', 'h_max_10', 'h_max_0_only', 'h_max_10_only']:
         local_scenario = 'pop-b_econ-c_fuel-c'
     elif name_config_path == 'h_min' or name_config_path == 'l_min' or name_config_path in ['h_min_zero', 'h_min_5dm', 'h_min_10dm']:
         local_scenario = 'pop-f_econ-c_fuel-c'
+    '''
+    local_scenario = 'pop-baseline16_econ-c16_fuel-c16'
 
     # --- Paths
     path_strategy_vars = os.path.join(config['DATA_PATHS']['path_strategy_vars'], name_config_path)
     name_region_set = os.path.join(config['PATHS']['path_local_data'], 'region_definitions', "lad_2016_uk_simplified.shp")
-    name_population_dataset = os.path.join(config['PATHS']['path_local_data'], 'scenarios', 'MISTRAL_pop_gva', 'data', '{}/population__lad.csv'.format(local_scenario))
-    name_gva_dataset = os.path.join(config['PATHS']['path_local_data'], 'scenarios', 'MISTRAL_pop_gva', 'data', '{}/gva_per_head__lad_sector.csv'.format(local_scenario))
-    name_gva_dataset_per_head = os.path.join(config['PATHS']['path_local_data'],'scenarios', 'MISTRAL_pop_gva', 'data', '{}/gva_per_head__lad.csv'.format(local_scenario))
+    name_population_dataset = os.path.join(config['PATHS']['path_local_data'], 'scenarios', 'MISTRAL_pop_gva', '{}/population__lad.csv'.format(local_scenario))
+    name_gva_dataset = os.path.join(config['PATHS']['path_local_data'], 'scenarios', 'MISTRAL_pop_gva', '{}/gva_per_head__lad_sector.csv'.format(local_scenario))
+    name_gva_dataset_per_head = os.path.join(config['PATHS']['path_local_data'],'scenarios', 'MISTRAL_pop_gva', '{}/gva_per_head__lad.csv'.format(local_scenario))
 
     # --------------------
     # Create scenario path
@@ -159,13 +159,15 @@ if __name__ == "__main__":
     # ----------------------------------------------------------------------
     # Load data
     # ----------------------------------------------------------------------
+    region_name_attribute ='lad_uk_2016'
     data['scenario_data'] = defaultdict(dict)
     data['enduses'], data['sectors'], data['fuels'], lookup_enduses, lookup_sector_enduses = data_loader.load_fuels(data['paths'])
     data['regions'] = read_data.get_region_names(name_region_set)
     data['reg_coord'] = basic_functions.get_long_lat_decimal_degrees(read_data.get_region_centroids(name_region_set))
-    data['scenario_data']['population'] = data_loader.read_scenario_data(name_population_dataset, region_name='lad_uk_2016', value_name='population')
-    data['scenario_data']['gva_industry'] = data_loader.read_scenario_data_gva(name_gva_dataset, region_name='lad_uk_2016', value_name='gva_per_head', all_dummy_data=False)
-    data['scenario_data']['gva_per_head'] = data_loader.read_scenario_data(name_gva_dataset_per_head, region_name='lad_uk_2016', value_name='gva_per_head')
+    data['scenario_data']['population'] = data_loader.read_scenario_data(name_population_dataset, region_name=region_name_attribute, value_name='population')
+
+    data['scenario_data']['gva_industry'] = data_loader.read_scenario_data_gva(name_gva_dataset, region_name=region_name_attribute, value_name='gva_per_head', all_dummy_data=False)
+    data['scenario_data']['gva_per_head'] = data_loader.read_scenario_data(name_gva_dataset_per_head, region_name=region_name_attribute, value_name='gva_per_head')
 
     # -----------------------------
     # Assumptions
@@ -196,7 +198,7 @@ if __name__ == "__main__":
     # -----------------------------------------------------------------------------
     # Load standard strategy variable values from .py file
     # Containing full information
-    # -----------------------------------------------------------------------------        
+    # -----------------------------------------------------------------------------
     default_streategy_vars = strategy_vars_def.load_param_assump(
         default_values=True)
 
@@ -241,16 +243,32 @@ if __name__ == "__main__":
     data['assumptions'].technologies.update(technologies)
 
     if config['CRITERIA']['virtual_building_stock_criteria']:
-        data['scenario_data']['floor_area']['rs_floorarea'], data['scenario_data']['floor_area']['ss_floorarea'], data['service_building_count'], rs_regions_without_floorarea, ss_regions_without_floorarea = data_loader.floor_area_virtual_dw(
+        (
+            rs_floorarea,
+            ss_floorarea,
+            service_building_count,
+            rs_regions_without_floorarea,
+            ss_regions_without_floorarea
+        ) = data_loader.floor_area_virtual_dw(
             data['regions'],
             data['sectors'],
             data['local_paths'],
             data['scenario_data']['population'][data['assumptions'].base_yr],
-            data['assumptions'].base_yr)
+            data['assumptions'].base_yr
+        )
+
+        data['scenario_data']['floor_area']['rs_floorarea'] = rs_floorarea
+        data['scenario_data']['floor_area']['ss_floorarea'] = ss_floorarea
+        data['service_building_count'] = service_building_count
 
         # Add all areas with no floor area data
         data['assumptions'].update("rs_regions_without_floorarea", rs_regions_without_floorarea)
         data['assumptions'].update("ss_regions_without_floorarea", ss_regions_without_floorarea)
+    else:
+        # Not (yet?) handled in this runner
+        raise NotImplementedError(
+            "Expected virtual_building_stock_criteria to be True, " \
+            "loading floor area not implemented")
 
     print("Start Energy Demand Model with python version: " + str(sys.version))
     print("-----------------------------------------------")
@@ -267,16 +285,13 @@ if __name__ == "__main__":
     # Make selection of weather stations and data
     # Load all temperature and weather station data
     # ---------------------------------------------
-    data['weather_stations'], data['temp_data'] = data_loader.load_temp_data(
-        data['local_paths'],
+    data['temp_data'] = data_loader.load_temp_data(
         sim_yrs=sim_yrs,
+        regions=data['regions'],
         weather_realisation=weather_realisation,
         path_weather_data=path_weather_data,
-        same_base_year_weather=False,
-        crit_temp_min_max=config['CRITERIA']['crit_temp_min_max'],
-        load_np=False,
-        load_parquet=False,
-        load_csv=True)
+        region_name_attribute=region_name_attribute,
+        same_base_year_weather=False)
 
     # ------------------------------------------------------------
     # Disaggregate national energy demand to regional demands
@@ -405,7 +420,6 @@ if __name__ == "__main__":
     # Main model run function
     # -----------------------
     for sim_yr in data['assumptions'].sim_yrs:
-
         print("Local simulation for year:  " + str(sim_yr))
         setattr(data['assumptions'], 'curr_yr', sim_yr) # Set current year
 
@@ -445,7 +459,6 @@ if __name__ == "__main__":
             data,
             config['CRITERIA'],
             data['assumptions'],
-            data['weather_stations'],
             weather_yr=weather_yr_scenario,
             weather_by=data['assumptions'].weather_by)
 
@@ -464,7 +477,7 @@ if __name__ == "__main__":
                 config['CRITERIA']['plot_crit'])
 
         # -------------------------------------
-        # # Generate YAML file with keynames for `sector_model`
+        # Generate ouputs
         # -------------------------------------
         if config['CRITERIA']['mode_constrained']:
             supply_results = demand_supply_interaction.constrained_results(
@@ -474,7 +487,7 @@ if __name__ == "__main__":
                 data['assumptions'].technologies)
         else:
             supply_results = demand_supply_interaction.unconstrained_results(
-                sim_obj.results_unconstrained,
+                sim_obj.results_unconstrained_no_heating,
                 data['assumptions'].submodels_names)
 
         # --------------------------
@@ -502,7 +515,7 @@ if __name__ == "__main__":
             # Write annual results to txt files
             # -------------------------------------------
             print("... Start writing results to file: " + str(data['weather_yr_result_paths']['data_results_model_run_results_txt']))
-            plot_only_selection = True 
+            plot_only_selection = True
             if plot_only_selection:
 
                 # Write only total region
@@ -562,6 +575,9 @@ if __name__ == "__main__":
 
             print("... Finished writing results to file")
 
+    for key_name in sim_obj.supply_results.keys():
+        print("KEYNAME " + str(key_name))
+
     print("-------------------------")
     print("... Finished running HIRE")
     print("-------------------------")
