@@ -43,7 +43,6 @@ from energy_demand.dwelling_stock import dw_stock
 from energy_demand.profiles import load_factors
 from energy_demand.profiles import generic_shapes
 from energy_demand.basic import demand_supply_interaction
-from energy_demand.geography import weather_station_location
 
 class EnergyDemandModel(object):
     """ Main function of energy demand model. All submodels
@@ -66,7 +65,6 @@ class EnergyDemandModel(object):
             data,
             criterias,
             assumptions,
-            weather_stations,
             weather_yr,
             weather_by
         ):
@@ -79,18 +77,13 @@ class EnergyDemandModel(object):
         logging.debug("... generating dwelling stocks")
         lookups = lookup_tables.basic_lookups()
 
-        if criterias['virtual_building_stock_criteria']:
-            rs_dw_stock, ss_dw_stock = create_virtual_dwelling_stocks(
-                regions, assumptions.curr_yr, data, criterias)
+        rs_dw_stock, ss_dw_stock = create_virtual_dwelling_stocks(
+            regions, assumptions.curr_yr, data, criterias)
 
-            data['dw_stocks'] = {
-                lookups['submodels_names'][0]: rs_dw_stock,
-                lookups['submodels_names'][1]: ss_dw_stock,
-                lookups['submodels_names'][2]: None}
-        else:
-            # Create dwelling stock from imported data from newcastle
-            data = create_dwelling_stock(
-                regions, assumptions.curr_yr, data)
+        data['dw_stocks'] = {
+            lookups['submodels_names'][0]: rs_dw_stock,
+            lookups['submodels_names'][1]: ss_dw_stock,
+            lookups['submodels_names'][2]: None}
 
         # Initialise result container to aggregate results
         aggr_results = initialise_result_container(
@@ -102,11 +95,9 @@ class EnergyDemandModel(object):
         # -------------------------------------------
         # Simulate regions
         # -------------------------------------------
-        #_all_closest_weather_stations = []
         for reg_array_nr, region in enumerate(tqdm(regions)):
-
-            print("... Simulate: region %s, simulation year: %s, percent: (%s)",
-                region, assumptions.curr_yr, round((100/assumptions.reg_nrs)*reg_array_nr, 2), flush=True)
+            #print("... Simulate: region %s, simulation year: %s, percent: (%s)",
+            #    region, assumptions.curr_yr, round((100/assumptions.reg_nrs)*reg_array_nr, 2), flush=True)
             #logging.info("... Simulate: region %s, simulation year: %s, percent: (%s)",
             #    region, assumptions.curr_yr, round((100/assumptions.reg_nrs)*reg_array_nr, 2))
             all_submodels = simulate_region(
@@ -114,10 +105,8 @@ class EnergyDemandModel(object):
                 data,
                 criterias,
                 assumptions,
-                weather_stations,
                 weather_yr,
                 weather_by)
-            #_all_closest_weather_stations.append(all_submodels)#weather_region_id
     
             # ---------------------------------------------
             # Aggregate results specifically over regions
@@ -243,6 +232,7 @@ def aggregate_across_all_regs(
     # ----------------------------------------------------
     # Generate dict for supply model
     # ----------------------------------------------------
+    print("Mode: " + str(criterias['mode_constrained']))
     if criterias['mode_constrained']:
         aggr_results['supply_results'] = demand_supply_interaction.constrained_results(
             aggr_results['results_constrained'],
@@ -251,7 +241,7 @@ def aggregate_across_all_regs(
             technologies)
     else:
         aggr_results['supply_results'] = demand_supply_interaction.unconstrained_results(
-            aggr_results['results_unconstrained'],
+            aggr_results['results_unconstrained_no_heating'],
             assumptions.submodels_names)
 
     return aggr_results
@@ -309,7 +299,6 @@ def simulate_region(
         data,
         criterias,
         assumptions,
-        weather_stations,
         weather_yr,
         weather_by
     ):
@@ -329,24 +318,16 @@ def simulate_region(
     """
     submodel_names = assumptions.submodels_names
 
-    # Get closest weather region object
-    weather_region_id = weather_station_location.get_closest_station(
-        latitude_reg=data['reg_coord'][region]['latitude'],
-        longitude_reg=data['reg_coord'][region]['longitude'],
-        weather_stations=weather_stations)
-
     # ----------------------------
     # Create Base year and current weather Regions
     # ----------------------------
     weather_region_cy = WeatherRegion(
-        name=weather_region_id,
-        latitude=weather_stations[weather_region_id]['latitude'],
-        longitude=weather_stations[weather_region_id]['longitude'],
+        name=region,
         assumptions=assumptions,
         technologies=assumptions.technologies,
         enduses=data['enduses'],
-        temp_by=data['temp_data'][weather_by][weather_region_id],
-        temp_cy=data['temp_data'][weather_yr][weather_region_id],
+        temp_by=data['temp_data'][weather_by][region],
+        temp_cy=data['temp_data'][weather_yr][region],
         tech_lp=data['tech_lp'],
         sectors=data['sectors'],
         crit_temp_min_max=criterias['crit_temp_min_max'])
@@ -406,7 +387,6 @@ def simulate_region(
                     dw_stock=dw_stock,
                     reg_scen_drivers=assumptions.scenario_drivers,
                     flat_profile_crit=flat_profile_crit)
-    #return weather_region_id
 
 def fuel_aggr(
         sector_models,
