@@ -2,9 +2,9 @@
 """
 import logging
 from collections import defaultdict
-import time
 import numpy as np
 
+from energy_demand.basic import lookup_tables
 from energy_demand.geography import spatial_diffusion
 from energy_demand.read_write import read_data
 from energy_demand.scripts import (s_fuel_to_service, s_generate_sigmoid)
@@ -33,7 +33,7 @@ def get_all_narrative_timesteps(switches_list):
         switches_list)
 
     for enduse in enduses:
-        narrative_timesteps[enduse] = set([])
+        narrative_timesteps[enduse] = set()
 
         for switch in switches_list:
             if switch.enduse == enduse:
@@ -133,19 +133,22 @@ def create_spatial_diffusion_factors(
     return f_reg, f_reg_norm, f_reg_norm_abs, crit_all_the_same
 
 def switch_calculations(
-        simulated_yrs,
+        sim_yrs,
         data,
         f_reg,
         f_reg_norm,
         f_reg_norm_abs,
-        crit_all_the_same
+        crit_all_the_same,
+        service_switches,
+        fuel_switches,
+        capacity_switches
     ):
     """This function creates sigmoid diffusion values based
     on defined switches
 
     Arguments
     ----------
-    simulated_yrs : list
+    sim_yrs : list
         Simulated years
     data : dict
         Data container
@@ -168,17 +171,16 @@ def switch_calculations(
         for sector in data['sectors'][submodel]:
             s_tech_by_p[sector], s_fueltype_by_p[sector] = s_fuel_to_service.get_s_fueltype_tech(
                 data['enduses'][submodel],
-                data['lookups']['fueltypes'],
                 data['assumptions'].fuel_tech_p_by,
                 data['fuels'][submodel],
-                data['technologies'],
+                data['assumptions'].technologies,
                 sector)
 
     # Get all defined narrative timesteps of all switch types
     narrative_timesteps = {}
-    narrative_timesteps.update(get_all_narrative_timesteps(data['assumptions'].service_switches))
-    narrative_timesteps.update(get_all_narrative_timesteps(data['assumptions'].fuel_switches))
-    narrative_timesteps.update(get_all_narrative_timesteps(data['assumptions'].capacity_switches))
+    narrative_timesteps.update(get_all_narrative_timesteps(service_switches))
+    narrative_timesteps.update(get_all_narrative_timesteps(fuel_switches))
+    narrative_timesteps.update(get_all_narrative_timesteps(capacity_switches))
 
     # ========================================================================================
     # Capacity switches
@@ -187,16 +189,16 @@ def switch_calculations(
     # ========================================================================================
 
     # Convert globally defined switches to regional switches
-    f_diffusion = f_reg_norm_abs #TODO EXPLAIN # Select diffusion value
+    f_diffusion = f_reg_norm_abs # Select diffusion value
 
     reg_capacity_switches = global_to_reg_capacity_switch(
-        data['regions'], data['assumptions'].capacity_switches, f_diffusion=f_diffusion)
+        data['regions'], capacity_switches, f_diffusion=f_diffusion)
 
     service_switches_incl_cap = fuel_service_switch.capacity_switch(
         narrative_timesteps,
         data['regions'],
         reg_capacity_switches,
-        data['technologies'],
+        data['assumptions'].technologies,
         data['fuels']['aggr_sector_fuels'],
         data['assumptions'].fuel_tech_p_by,
         data['assumptions'].base_yr)
@@ -216,7 +218,7 @@ def switch_calculations(
     f_diffusion = f_reg_norm
 
     share_s_tech_ey_p = fuel_service_switch.autocomplete_switches(
-        data['assumptions'].service_switches,
+        service_switches,
         data['assumptions'].specified_tech_enduse_by,
         s_tech_by_p,
         data['enduses'],
@@ -230,39 +232,75 @@ def switch_calculations(
     # ========================================================================================
     # Fuel switches
     #
-    # Calculate sigmoid diffusion considering fuel switches
-    # and service switches. As inputs, service (and thus also capacity switches) are used
+    # Calculate sigmoid diffusion considering fuel switches and service switches.
+    # As inputs, service (and thus also capacity switches) are used
     # ========================================================================================
-    sig_param_tech = defaultdict(dict)
+    diffusion_param_tech = defaultdict(dict)
 
-    for submodel in data['assumptions'].submodels_names:
-        for enduse in data['enduses'][submodel]:
-            for sector in data['sectors'][submodel]:
+    for submodel_name in data['assumptions'].submodels_names:
+        for enduse in data['enduses'][submodel_name]:
+            for sector in data['sectors'][submodel_name]:
+                logging.debug("... calculating fuel switches {}  {}  {}".format(submodel_name, enduse, sector))
 
-                sig_param_tech[enduse][sector] = sig_param_calc_incl_fuel_switch(
+                diffusion_param_tech[enduse][sector] = sig_param_calc_incl_fuel_switch(
                     narrative_timesteps,
                     data['assumptions'].base_yr,
                     data['assumptions'].crit_switch_happening,
-                    data['technologies'],
+                    data['assumptions'].technologies,
                     enduse=enduse,
-                    fuel_switches=data['assumptions'].fuel_switches,
+                    sector=sector,
+                    fuel_switches=fuel_switches,
                     s_tech_by_p=s_tech_by_p[sector][enduse],
                     s_fueltype_by_p=s_fueltype_by_p[sector][enduse],
                     share_s_tech_ey_p=share_s_tech_ey_p,
-                    fuel_tech_p_by=data['assumptions'].fuel_tech_p_by[enduse],
+                    fuel_tech_p_by=data['assumptions'].fuel_tech_p_by[enduse][sector],
                     regions=data['regions'],
-                    sector=sector,
                     crit_all_the_same=crit_all_the_same)
 
     # ------------------
-    # Calculate annual values based on calculated
-    # parameters for every simulation year
+    # Calculate annual values based on calculated parameters for every simulation year
     # ------------------
     annual_tech_diff_params = s_scenario_param.calc_annual_switch_params(
-        simulated_yrs,
+        sim_yrs,
         data['regions'],
-        dict(sig_param_tech))
+        dict(diffusion_param_tech),
+        base_yr=data['assumptions'].base_yr,
+        s_tech_by_p=s_tech_by_p)
 
+    # ------------------------------------------------------
+    # Test whether the calculated service shares sum up to 1
+    # and if not, then distribute not assigned demand according to
+    # base year distribution
+    # Can happen because multiple sigmoid for different technologies
+    # ------------------------------------------------------
+    for region in annual_tech_diff_params:
+        for enduse in annual_tech_diff_params[region]:
+            for sector in annual_tech_diff_params[region][enduse]:
+
+                for year in sim_yrs:
+                    if annual_tech_diff_params[region][enduse][sector] != []:
+                        assigned_service_p = 0
+                        for tech in annual_tech_diff_params[region][enduse][sector]:
+                            #print("TECH {}  {} {}".format(tech, enduse, sector))
+                            assigned_service_p += annual_tech_diff_params[region][enduse][sector][tech][year]
+
+                        # Distribute if not sum up to one according to base year distribution
+                        if round(assigned_service_p, 2) != 1:
+                            total_not_assined = 1 - assigned_service_p
+
+                            for tech in annual_tech_diff_params[region][enduse][sector]:
+                                # Fraction in base year
+                                p_by = annual_tech_diff_params[region][enduse][sector][tech][data['assumptions'].base_yr]
+                                tech_to_add_not_assigned = total_not_assined * p_by
+                                annual_tech_diff_params[region][enduse][sector][tech][year] += tech_to_add_not_assigned
+
+                        assigned_service_p = 0
+                        for tech in annual_tech_diff_params[region][enduse][sector]:
+                            assigned_service_p += annual_tech_diff_params[region][enduse][sector][tech][year]
+
+                        assert round(assigned_service_p, 2) == 1
+
+    logging.info("Finished calculateding switch_calculations")
     return annual_tech_diff_params
 
 def spatial_explicit_modelling_strategy_vars(
@@ -276,25 +314,32 @@ def spatial_explicit_modelling_strategy_vars(
     ):
     """
     Spatial explicit modelling of scenario variables
-    based on narratives. From UK factors to regional specific factors
-    Convert strategy variables to regional variables
+    based on narratives. Convert strategy variables
+    (e.g. country level) to regional variables.
 
     Arguments
     ---------
-    assumptions : dict
-    regions
-
+    strategy_vars : dict
+        All non_spatial strategy variables
+    spatially_modelled_vars : dict
+        All spatial variables
+    regions : dict
+        Regions
+    fuel_disagg : dict
+        Disaggregated fuel
+    f_reg, f_reg_norm, f_reg_norm_abs : dict
+        Spatial factors
     """
     regional_vars = {}
 
     # Iterate strategy variables and calculate regional variable
     for var_name, strategy_var in strategy_vars.items():
-        logging.info("...Spatially explicit diffusion modelling %s", var_name)
+        logging.debug("...Spatially explicit diffusion modelling %s", var_name)
 
-        single_dim_var = narrative_related.get_crit_single_dim_var(strategy_var)
+        single_dim_var = narrative_related.crit_dim_var(strategy_var)
 
         if single_dim_var:
-            new_narratives = create_regional_narratives(
+            regional_vars[var_name] = get_regional_narrative(
                 var_name,
                 strategy_var,
                 spatially_modelled_vars,
@@ -303,27 +348,38 @@ def spatial_explicit_modelling_strategy_vars(
                 f_reg,
                 f_reg_norm,
                 f_reg_norm_abs)
-            regional_vars[var_name] = new_narratives
         else:
             regional_vars[var_name] = {}
 
-            for sub_var_name, sub_strategy_var in strategy_var.items():
+            for sub_var_name, sector_sub_strategy_var in strategy_var.items():
+                regional_vars[var_name][sub_var_name] = {}
+                if type(sector_sub_strategy_var) is dict: # sectors defined
+                    for sector, sub_strategy_var in sector_sub_strategy_var.items():
+                        regional_vars[var_name][sub_var_name][sector] = get_regional_narrative(
+                            sub_var_name,
+                            sub_strategy_var,
+                            spatially_modelled_vars,
+                            regions,
+                            fuel_disagg,
+                            f_reg,
+                            f_reg_norm,
+                            f_reg_norm_abs)
+                else:
+                    regional_vars[var_name][sub_var_name] = get_regional_narrative(
+                        sub_var_name,
+                        sector_sub_strategy_var,
+                        spatially_modelled_vars,
+                        regions,
+                        fuel_disagg,
+                        f_reg,
+                        f_reg_norm,
+                        f_reg_norm_abs)
 
-                new_narratives = create_regional_narratives(
-                    sub_var_name,
-                    sub_strategy_var,
-                    spatially_modelled_vars,
-                    regions,
-                    fuel_disagg,
-                    f_reg,
-                    f_reg_norm,
-                    f_reg_norm_abs)
-
-                regional_vars[var_name][sub_var_name] = new_narratives
+                regional_vars[var_name] = dict(regional_vars[var_name])
 
     return regional_vars
 
-def create_regional_narratives(
+def get_regional_narrative(
         var_name,
         strategy_vars,
         spatially_modelled_vars,
@@ -333,7 +389,30 @@ def create_regional_narratives(
         f_reg_norm,
         f_reg_norm_abs
     ):
+    """Spatial explicit modelling of scenario variable
+    based on narratives. Convert strategy variables
+    (e.g. country level) to regional variables.
 
+    Arguments
+    ---------
+    var_name : str
+        Variable name
+    strategy_vars : dict
+        All non_spatial strategy variables
+    spatially_modelled_vars : dict
+        All spatial variables
+    regions : dict
+        Regions
+    fuel_disagg : dict
+        Disaggregated fuel
+    f_reg, f_reg_norm, f_reg_norm_abs : dict
+        Spatial factors
+
+    Returns
+    ------
+    new_narratives : list
+        Created narratives
+    """
     new_narratives = []
     for narrative in strategy_vars:
 
@@ -345,7 +424,7 @@ def create_regional_narratives(
             regional_vars_by = {}
             regional_vars_ey = {}
 
-            # Check whether scenario varaible is regionally modelled
+            # Check whether scenario variable is regionally modelled
             if var_name not in spatially_modelled_vars:
 
                 # Variable is not spatially modelled
@@ -353,15 +432,15 @@ def create_regional_narratives(
                     regional_vars_ey[region] = float(narrative['value_ey'])
                     regional_vars_by[region] = float(narrative['value_by'])
             else:
-                if narrative['affected_enduse'] == []:
+                if narrative['enduse'] == []:
                     logging.info(
-                        "For scenario var %s no affected enduse is defined. Thus speed is used for diffusion",
-                            var_name)
+                        "For variable %s no affected enduse is defined. Thus speed is used for diffusion modelling",
+                        var_name)
                     fuels_reg = {}
                 else:
                     # Get enduse specific fuel for each region
                     fuels_reg = spatial_diffusion.get_enduse_regs(
-                        enduse=narrative['affected_enduse'],
+                        enduse=narrative['enduse'],
                         fuels_disagg=[
                             fuel_disagg['residential'],
                             fuel_disagg['service'],
@@ -450,20 +529,17 @@ def global_to_reg_capacity_switch(
     return reg_capacity_switch
 
 def sum_across_all_submodels_regs(
-        fueltypes_nr,
         regions,
         submodels
     ):
     """Calculate total sum of fuel per region
     """
+    fueltypes_nr = lookup_tables.basic_lookups()['fueltypes_nr']
     fuel_aggregated_regs = {}
 
     for region in regions:
-
         tot_reg = np.zeros((fueltypes_nr), dtype="float")
-
         for submodel_fuel_disagg in submodels:
-
             for fuel_sector_enduse in submodel_fuel_disagg[region].values():
 
                 # Test if fuel for sector
@@ -509,13 +585,13 @@ def sig_param_calc_incl_fuel_switch(
         crit_switch_happening,
         technologies,
         enduse,
+        sector,
         fuel_switches,
         s_tech_by_p,
         s_fueltype_by_p,
         share_s_tech_ey_p,
         fuel_tech_p_by,
         regions=False,
-        sector=False,
         crit_all_the_same=True
     ):
     """Calculate sigmoid diffusion paramaters considering
@@ -558,16 +634,10 @@ def sig_param_calc_incl_fuel_switch(
     service_switches_out : list
         Service switches
     """
+    sig_param_tech = {}
     if sum(s_tech_by_p.values()) == 0: # no fuel is defined for enduse
-        #logging.info("no fuel is defined for enduse `{}` and sector `{}`".format(enduse, sector))
-        sig_param_tech = {}
+        logging.debug("no fuel is defined for enduse `{}` and sector `{}`".format(enduse, sector))
     else:
-
-        if not sector:
-            fuel_tech_p_by = fuel_tech_p_by
-        else:
-            fuel_tech_p_by = fuel_tech_p_by[sector]
-
         if share_s_tech_ey_p == {}:
             pass
         else:
@@ -583,11 +653,6 @@ def sig_param_calc_incl_fuel_switch(
         _, crit_fuel_switch = s_generate_sigmoid.get_tech_installed(
             enduse, fuel_switches)
 
-        # ------------------------------------------
-        # Initialisations
-        # ------------------------------------------
-        sig_param_tech = {}
-
         # Test if switch is defined
         crit_switch_service = fuel_service_switch.get_switch_criteria(
             enduse, sector, crit_switch_happening)
@@ -597,18 +662,23 @@ def sig_param_calc_incl_fuel_switch(
         elif crit_switch_service and crit_fuel_switch:
             raise Exception("Error: a fuel and service switch is defined at the same time %s", enduse)
         else:
-
-            # Only calculate for one reg
-            any_region = regions[0]
-
-            # Years of narrative
-            switch_yrs = narrative_timesteps[enduse]
+            any_region = regions[0] # Only calculate for one reg
+            switch_yrs = narrative_timesteps[enduse] # Years of narrative
 
             # Iterate over years defined in narrative
             for switch_yr_cnt, switch_yr in enumerate(switch_yrs):
-
                 sig_param_tech[switch_yr] = {}
 
+                # -------------------------
+                # Get starting year of narrative
+                # -------------------------
+                if switch_yr_cnt == 0: 
+                    switch_yr_start = base_yr
+                    s_tech_last_narrative_step = s_tech_by_p
+                else: # If more than one switch_yr, then take previous year
+                    switch_yr_start = switch_yrs[switch_yr_cnt - 1]
+                    s_tech_last_narrative_step = s_tech_switched_p[any_region][switch_yr_start]
+
                 # ------------------------------------------
                 # Service switch
                 #
@@ -616,6 +686,7 @@ def sig_param_calc_incl_fuel_switch(
                 # switches and the diffusion parameters
                 # ------------------------------------------
                 if crit_switch_service:
+                    logging.debug(".... service switch")
 
                     # Calculate only from service switch
                     s_tech_switched_p = share_s_tech_ey_p
@@ -623,7 +694,7 @@ def sig_param_calc_incl_fuel_switch(
                     # Calculate sigmoid diffusion parameters
                     l_values_sig = s_generate_sigmoid.get_l_values(
                         technologies=technologies,
-                        technologies_to_consider=s_tech_by_p.keys(),
+                        technologies_to_consider=s_tech_last_narrative_step.keys(),
                         regions=regions)
                 elif crit_fuel_switch:
                     s_tech_switched_p = defaultdict(dict)
@@ -635,23 +706,21 @@ def sig_param_calc_incl_fuel_switch(
                 # Fuel switch
                 # ------------------------------------------
                 if crit_fuel_switch:
-                    """
-                    Calculate future service share after fuel switches
-                    and calculte sigmoid diffusion paramters.
-                    """
+                    logging.info(".... fuel switch")
+                    """Calculate future service share after fuel switches
+                    and calculte sigmoid diffusion paramters."""
                     # Get fuel switches of enduse and switch_yr
                     enduse_fuel_switches = fuel_service_switch.get_switches_of_enduse(
                         fuel_switches, enduse, switch_yr, crit_region=False)
 
                     if crit_all_the_same:
-                        logging.info("... calculating fuel switches (not regional specific): {}".format(enduse))
-
+                        logging.debug("... calculating fuel switches (not regional specific): {}".format(enduse))
                         # Calculate service demand after fuel switches for each technology
                         s_tech_switched_p_values_all_regs = s_generate_sigmoid.calc_service_fuel_switched(
                             enduse_fuel_switches,
                             technologies,
                             s_fueltype_by_p,
-                            s_tech_by_p,
+                            s_tech_last_narrative_step,
                             fuel_tech_p_by,
                             'actual_switch')
 
@@ -660,16 +729,18 @@ def sig_param_calc_incl_fuel_switch(
                             s_tech_switched_p_values_all_regs,
                             enduse_fuel_switches,
                             technologies,
-                            s_tech_by_p.keys(),
+                            s_tech_last_narrative_step.keys(),
                             s_fueltype_by_p,
-                            s_tech_by_p,
+                            s_tech_last_narrative_step,
                             fuel_tech_p_by)
 
                         for region in regions:
                             s_tech_switched_p[region][switch_yr] = s_tech_switched_p_values_all_regs
                             l_values_sig[region] = l_values_all_regs
+
+                        s_tech_switched_p = dict(s_tech_switched_p)
                     else:
-                        logging.info("... calculating fuel switches (regional specific): {}".format(enduse))
+                        logging.debug("... calculating fuel switches (regional specific): {}".format(enduse))
                         for region in regions:
 
                             # Calculate service demand after fuel switches for each technology
@@ -677,7 +748,7 @@ def sig_param_calc_incl_fuel_switch(
                                 enduse_fuel_switches,
                                 technologies,
                                 s_fueltype_by_p,
-                                s_tech_by_p,
+                                s_tech_last_narrative_step,
                                 fuel_tech_p_by,
                                 'actual_switch')
 
@@ -686,44 +757,32 @@ def sig_param_calc_incl_fuel_switch(
                                 s_tech_switched_p[region][switch_yr],
                                 enduse_fuel_switches,
                                 technologies,
-                                s_tech_by_p.keys(),
+                                s_tech_last_narrative_step.keys(),
                                 s_fueltype_by_p,
-                                s_tech_by_p,
+                                s_tech_last_narrative_step,
                                 fuel_tech_p_by)
 
-                # -------------------------
-                # Get starting year of narrative story
-                # -------------------------
-                if switch_yr_cnt == 0: 
-                    switch_yr_start = base_yr
-                else: # If more than one switch_yr, then take previous year
-                    switch_yr_start = switch_yrs[switch_yr_cnt - 1]
-                    
+                        s_tech_switched_p = dict(s_tech_switched_p)
+
                 # -----------------------------------------------
                 # Calculates parameters for sigmoid diffusion of
                 # technologies which are switched to/installed.
                 # -----------------------------------------------
-                #logging.debug("---------- switches %s %s %s", enduse, crit_switch_service, crit_fuel_switch)
                 if crit_all_the_same:
-                    logging.info("... calc parameters of `{}` for year `{}`".format(enduse, switch_yr))
-
-                    # Calculate for one region
+                    logging.debug("... calc parameters of `{}` for year `{}`  {}".format(enduse, switch_yr, sector))
                     sig_param_tech_all_regs_value = s_generate_sigmoid.tech_sigmoid_parameters(
                         switch_yr,
                         switch_yr_start,
                         technologies,
                         l_values_sig[any_region],
-                        s_tech_by_p,
+                        s_tech_last_narrative_step,
                         s_tech_switched_p[any_region][switch_yr])
 
                     for region in regions:
                         sig_param_tech[switch_yr][region] = sig_param_tech_all_regs_value
                 else:
-                    logging.info("... calc region specific parameters of `{}` for year `{}` sector: {}".format(enduse, switch_yr, sector))
-
-                    start = time.time()
+                    logging.debug("... calc region specific parameters of `{}` for year `{}` sector: {}".format(enduse, switch_yr, sector))
                     for region in regions:
-                        #print("REGION " + str(region), flush=True)
                         sig_param_tech[switch_yr][region] = s_generate_sigmoid.tech_sigmoid_parameters(
                             switch_yr,
                             switch_yr_start,
@@ -731,13 +790,14 @@ def sig_param_calc_incl_fuel_switch(
                             l_values_sig[region],
                             s_tech_by_p,
                             s_tech_switched_p[region][switch_yr])
-                    end = time.time()
-
-                    print("Time use for sigmoid parameter calaulations (reduce number of iteraitons for speedup): " + str(end - start), flush=True)
 
     return sig_param_tech
 
-def get_sector__enduse_switches(sector_to_match, enduse_to_match, switches):
+def get_sector__enduse_switches(
+        sector_to_match,
+        enduse_to_match,
+        switches
+    ):
     """Get all switches of a sector if the switches are
     defined specifically for a sector. If the switches are
     not specifically for a sector, return all switches
@@ -758,12 +818,6 @@ def get_sector__enduse_switches(sector_to_match, enduse_to_match, switches):
     switches_out = set([])
 
     for switch in switches:
-
-        # If sector is None
-        '''if not switch.sector and not sector_to_match:
-            switches.add(switch)
-        else:'''
-
         if switch.sector == sector_to_match and switch.enduse == enduse_to_match:
             switches_out.add(switch)
         elif not switch.sector and switch.enduse == enduse_to_match: # Not defined specifically for sectors and add all
@@ -771,4 +825,4 @@ def get_sector__enduse_switches(sector_to_match, enduse_to_match, switches):
         else:
             pass
 
-    return list(switches_out)
\ No newline at end of file
+    return list(switches_out)
