@@ -47,7 +47,6 @@ def disaggr_demand(data, crit_temp_min_max, spatial_calibration=False):
         data['scenario_data'],
         data['assumptions'],
         data['reg_coord'],
-        data['weather_stations'], # Base year data used to disaggregate demand
         data['temp_data'][base_yr], # Base year data used to disaggregate demand
         data['sectors'],
         data['enduses'],
@@ -194,7 +193,6 @@ def disaggregate_base_demand(
         scenario_data,
         assumptions,
         reg_coord,
-        weather_stations,
         temp_data,
         sectors,
         enduses,
@@ -220,8 +218,6 @@ def disaggregate_base_demand(
         Assumptions
     reg_coord : dict
         Region coordinates
-    weather_stations : dict
-        Weather stations
     temp_data : dict
         Temperature data
     sectors : dict
@@ -249,8 +245,6 @@ def disaggregate_base_demand(
         scenario_data,
         pop_for_disagg,
         assumptions,
-        reg_coord,
-        weather_stations,
         temp_data,
         enduses['residential'],
         crit_limited_disagg_pop_hdd,
@@ -266,9 +260,7 @@ def disaggregate_base_demand(
         scenario_data,
         pop_for_disagg,
         regions,
-        reg_coord,
         temp_data,
-        weather_stations,
         enduses['service'],
         sectors['service'],
         crit_limited_disagg_pop_hdd,
@@ -280,8 +272,6 @@ def disaggregate_base_demand(
     is_fuel_disagg = is_disaggregate(
         assumptions,
         temp_data,
-        reg_coord,
-        weather_stations,
         fuels['industry'],
         regions,
         enduses['industry'],
@@ -300,9 +290,7 @@ def ss_disaggregate(
         scenario_data,
         pop_for_disagg,
         regions,
-        reg_coord,
         temp_data,
-        weather_stations,
         enduses,
         sectors,
         crit_limited_disagg_pop_hdd,
@@ -327,16 +315,12 @@ def ss_disaggregate(
         t_base_heating=assumptions.t_bases.ss_t_heating,
         regions=regions,
         temp_data=temp_data,
-        reg_coord=reg_coord,
-        weather_stations=weather_stations,
         crit_temp_min_max=crit_temp_min_max)
 
     ss_cdd_individ_region = hdd_cdd.get_cdd_country(
         t_base_cooling=assumptions.t_bases.ss_t_cooling,
         regions=regions,
         temp_data=temp_data,
-        reg_coord=reg_coord,
-        weather_stations=weather_stations,
         crit_temp_min_max=crit_temp_min_max)
 
     # ---------------------------------------------
@@ -453,15 +437,23 @@ def ss_disaggr(
         for sector in sectors:
 
             # Sector specific ino
-            reg_floor_area = scenario_data['floor_area']['ss_floorarea'][base_yr][region][sector]
+            try:
+                reg_floor_area = scenario_data['floor_area']['ss_floorarea'][base_yr][region][sector]
+            except IndexError: 
+                reg_floor_area = scenario_data['floor_area']['ss_floorarea'][base_yr][region] # no sector specific data available
 
             try:
                 nr_sector_cnt_building = lu_building_cnt[sector]
-                reg_sector_building_cnt = service_building_count[nr_sector_cnt_building][region]
+                try:
+                    reg_sector_building_cnt = service_building_count[nr_sector_cnt_building][region]
+                except IndexError:
+                    print("service_building_count")
+                    print(service_building_count)
+                    reg_sector_building_cnt = service_building_count[region] # no sector specific data available
+
                 tot_building_cnt[sector] += reg_sector_building_cnt
             except KeyError:
-                #logging.debug("No building data for region {}".format(region))
-                pass
+                pass #logging.debug("No building data for region {}".format(region))
 
             # National disaggregation factors
             tot_floor_area[sector] += reg_floor_area
@@ -506,9 +498,12 @@ def ss_disaggr(
                         reg_diasg_factor = p_pop
 
                 elif crit_full_disagg:
-
-                    reg_floor_area = scenario_data['floor_area']['ss_floorarea'][base_yr][region][sector]
-
+                    
+                    try:
+                        reg_floor_area = scenario_data['floor_area']['ss_floorarea'][base_yr][region][sector]
+                    except IndexError:
+                        reg_floor_area = scenario_data['floor_area']['ss_floorarea'][base_yr][region]
+        
                     # ----
                     # logging.debug(" ... Disaggregation ss: populaton, HDD, floor_area")
                     # ----
@@ -543,8 +538,6 @@ def ss_disaggr(
 def is_disaggregate(
         assumptions,
         temp_data,
-        reg_coord,
-        weather_stations,
         is_national_fuel,
         regions,
         enduses,
@@ -583,8 +576,6 @@ def is_disaggregate(
         t_base_heating=assumptions.t_bases.is_t_heating,
         regions=regions,
         temp_data=temp_data,
-        reg_coord=reg_coord,
-        weather_stations=weather_stations,
         crit_temp_min_max=crit_temp_min_max)
 
     is_fuel_disagg = {}
@@ -751,8 +742,6 @@ def rs_disaggregate(
         scenario_data,
         pop_for_disagg,
         assumptions,
-        reg_coord,
-        weather_stations,
         temp_data,
         enduses,
         crit_limited_disagg_pop_hdd,
@@ -790,8 +779,6 @@ def rs_disaggregate(
         t_base_heating=assumptions.t_bases.rs_t_heating,
         regions=regions,
         temp_data=temp_data,
-        reg_coord=reg_coord,
-        weather_stations=weather_stations,
         crit_temp_min_max=crit_temp_min_max)
 
     # ---------------------------------------
