@@ -4,12 +4,62 @@ This script calculates the three parameters of a sigmoid diffusion
 for every technology which is diffused and has a larger service
 fraction at the model end year
 """
-import logging
 from collections import defaultdict
 import numpy as np
 from scipy.optimize import curve_fit
+import pylab
+import matplotlib.pyplot as plt
+import matplotlib
+matplotlib.use('Agg') # Used to make it work in linux
+
 from energy_demand.technologies import diffusion_technologies
-#from energy_demand.plotting import plotting_program
+
+
+def plotout_sigmoid_tech_diff(
+        L_value,
+        technology,
+        xdata,
+        ydata,
+        fit_parameter,
+        plot_crit=False,
+        close_window_crit=True
+    ):
+    """Plot sigmoid diffusion
+    """
+    def close_event():
+        """Timer to close window automatically
+        """
+        plt.close()
+
+    x = np.linspace(1990, 2110, 300)
+    y = diffusion_technologies.sigmoid_function(x, L_value, *fit_parameter)
+
+    fig = plt.figure()
+
+    #creating a timer object and setting an interval
+    timer = fig.canvas.new_timer(interval=555)
+    timer.add_callback(close_event)
+
+    fig.set_size_inches(12, 8)
+    pylab.plot(xdata, ydata, 'o', label='base year and future market share')
+    pylab.plot(x, y, label='fit')
+
+    pylab.ylim(0, 1.05)
+    pylab.legend(loc='best')
+
+    pylab.xlabel('Time')
+    pylab.ylabel('Market share of technology on energy service')
+    pylab.title("Sigmoid diffusion of technology {}".format(technology))
+
+    if plot_crit:
+        if close_window_crit:
+            pylab.show()
+        else:
+            timer.start()
+            pylab.show()
+            pass
+    else:
+        pass
 
 def calc_sigmoid_parameters(
         l_value,
@@ -51,12 +101,7 @@ def calc_sigmoid_parameters(
     # ---------------------------------------------
     # Generate possible starting parameters for fit
     # ---------------------------------------------
-    start_param_list = [
-        0.0, 1.0, 0.0001, 0.001, 0.01] #,
-        #0.05, 0.1, 0.15, 0.2, 0.25, 0.3, 0.35,
-        #0.4, 0.45, 0.5, 0.55, 0.6, 0.65,
-        #10, 20, 30, 40, 50, 60, 70, 80,
-        #90, 100.0, 200.0, 400.0, 500.0, 1000, 10000]
+    start_param_list = [0.0, 1.0, 0.0001, 0.001, 0.01]
 
     # ---------------------------------------------
     # Fit
@@ -70,7 +115,7 @@ def calc_sigmoid_parameters(
                 round(start_param_list[cnt], 3)]
 
             # ------------------------------------------------
-            # Test if parameter[1] shoudl be minus or positive
+            # Test if parameter[1] should be minus or positive
             # ------------------------------------------------
             if ydata[0] < ydata[1]: # end point has higher value
                 crit_plus_minus = 'plus'
@@ -109,7 +154,6 @@ def calc_sigmoid_parameters(
                     if cnt >= len(start_param_list):
                         raise Exception("Error: Sigmoid curve fitting failed")
                 else:
-
                     # Check how good the fit is
                     y_calculated_ey = diffusion_technologies.sigmoid_function(
                         x_value=xdata[1],
@@ -129,16 +173,12 @@ def calc_sigmoid_parameters(
                     if (fit_measure_p_ey < (100.0 - error_range) or fit_measure_p_ey > (100.0 + error_range)) or (
                         fit_measure_p_by < (100.0 - error_range) or fit_measure_p_by > (100.0 + error_range)):
                         
-                        #logging.debug("... Fitting measure %s %s (percent) is not good enough",
-                        #    fit_measure_p_by, fit_measure_p_ey)
+                        #logging.debug("... Fitting measure %s %s (percent) is not good enough", fit_measure_p_by, fit_measure_p_ey)
                         successfull = False
                         cnt += 1
                     else:
                         successfull = True
-
-                        '''logging.info(
-                            ".... fitting successfull %s %s %s", fit_measure_p_ey, fit_measure_p_by, fit_parameter)
-                        plotting_program.plotout_sigmoid_tech_diff(
+                        '''plotout_sigmoid_tech_diff(
                             l_value,
                             "FINISHED FITTING",
                             xdata,
@@ -376,7 +416,7 @@ def calc_service_fuel_switched(
         s_rel_fraction_p = tech_fraction / service_tot_remaining
         s_tech_switched_p[tech] = s_rel_fraction_p * unaffected_service_to_distr_p
 
-        assert s_tech_switched_p[tech] >= 0 #NEW
+        assert s_tech_switched_p[tech] >= 0
 
     return dict(s_tech_switched_p)
 
@@ -509,14 +549,21 @@ def tech_sigmoid_parameters(
                                 rounding error, there might be very small
                                 differences in percentual service demand.
     """
+    def calc_m(x1, x2, y1, y2):
+        m = (y1-y2) / (x1 - x2)
+        return m
+
+    def calc_c(m, x1, y1):
+        c = y1 - (m * x1)
+        return c
+
     rounding_accuracy = 4       # Criteria how much difference in % can be rounded
-    linear_approx_crit = 0.001  # Criteria to simplify with linear approximation if difference is smaller (decimal) # 0.001
-    error_range = 0.0002        # Error how close the fit must be                                                   # 0.0002
-    number_of_iterations = 100  # Number of iterations of sigmoid fitting algorithm                                 # 1000
+    linear_approx_crit = 0.001  # Criteria to simplify with linear approximation if difference is smaller (decimal)
+    error_range = 0.0002        # Error how close the fit must be
+    number_of_iterations = 100  # Number of iterations of sigmoid fitting algorithm
 
     # Technologies to apply calculation
-    installed_techs = s_tech_switched_p.keys()
-
+    installed_techs = s_tech_by_p.keys()
     sig_params = defaultdict(dict)
 
     # Fitting criteria where the calculated sigmoid slope and midpoint can be provided limits
@@ -525,10 +572,8 @@ def tech_sigmoid_parameters(
     else:
         for tech in installed_techs:
 
-            # --------
             # Test whether technology has the market entry before or after base year,
             # If afterwards, set very small number in market entry year
-            # --------
             if technologies[tech].market_entry > switch_yr_start:
                 point_x_by = technologies[tech].market_entry
                 point_y_by = fit_assump_init
@@ -539,6 +584,8 @@ def tech_sigmoid_parameters(
                 # If the base year is the market entry year use a very small number
                 if point_y_by == 0:
                     point_y_by = fit_assump_init
+                #elif point_y_by == 1.0:
+                #    point_y_by = 1 - fit_assump_init
 
             # Future energy service demand
             point_x_ey = yr_until_switched
@@ -556,33 +603,22 @@ def tech_sigmoid_parameters(
             xdata = np.array([point_x_by, point_x_ey])
             ydata = np.array([point_y_by, point_y_ey])
 
-            '''logging.info(
-                "... create sigmoid diffusion %s - %s - %s - %s - l_val: %s - %s - %s lval: %s",
-                tech,
-                xdata,
-                ydata,
-                fit_assump_init,
-                l_values[tech],
-                point_y_by,
-                point_y_ey,
-                linear_approx_crit)'''
-
-            # Test wheter maximum diffusion is larger than simulated end year share
-            ## assert ydata[1] <= l_values[tech] + linear_approx_crit
-
             # If no change in by to ey but not zero (linear change)
             if (round(point_y_by, rounding_accuracy) == round(point_y_ey, rounding_accuracy)) and (
                     point_y_ey != fit_assump_init) and (
                         point_y_by != fit_assump_init):
-
+            #if 1 == 1:
                 # Linear diffusion (because by and ey share are identical)
                 sig_params[tech]['midpoint'] = 'linear'
                 sig_params[tech]['steepness'] = 'linear'
                 sig_params[tech]['l_parameter'] = 'linear'
+
+                # Calculate linear slope and linear y-intercept (with two data points)
+                sig_params[tech]['linear_slope'] = calc_m(xdata[0], xdata[1], ydata[0], ydata[1])
+                sig_params[tech]['linear_y_intercept'] = calc_c(sig_params[tech]['linear_slope'], xdata[0], ydata[0])
             else:
                 # Test if no increase or decrease or if no future potential share
-                if (point_y_by == fit_assump_init and point_y_ey == fit_assump_init) or (
-                        l_values[tech] == 0):
+                if (point_y_by == fit_assump_init and point_y_ey == fit_assump_init) or (l_values[tech] == 0):
                     sig_params[tech]['midpoint'] = None
                     sig_params[tech]['steepness'] = None
                     sig_params[tech]['l_parameter'] = None
@@ -590,14 +626,16 @@ def tech_sigmoid_parameters(
 
                     # If difference is smaller than a certain share, approximate with linear
                     if abs(ydata[1] - ydata[0]) < linear_approx_crit:
-                        #logging.info("Linear approximation...")
                         sig_params[tech]['midpoint'] = 'linear'
                         sig_params[tech]['steepness'] = 'linear'
                         sig_params[tech]['l_parameter'] = 'linear'
 
+                        # Calculate linear slope and linear y-intercept (with two data points)
+                        sig_params[tech]['linear_slope'] = calc_m(xdata[0], xdata[1], ydata[0], ydata[1])
+                        sig_params[tech]['linear_y_intercept'] = calc_c(sig_params[tech]['linear_slope'], xdata[0], ydata[0])
+
                     try:
                         # Parameter fitting
-                        ##print("----start fitting" ) #, flush=True)
                         fit_parameter = calc_sigmoid_parameters(
                             l_values[tech],
                             xdata,
@@ -608,17 +646,7 @@ def tech_sigmoid_parameters(
 
                         sig_params[tech]['midpoint'] = fit_parameter[0]
                         sig_params[tech]['steepness'] = fit_parameter[1]
-                        sig_params[tech]['l_parameter'] = l_values[tech] # maximum p
-
-                        '''if plot_sigmoid_diffusion:
-                            plotting_program.plotout_sigmoid_tech_diff(
-                                l_values[tech],
-                                tech,
-                                xdata,
-                                ydata,
-                                fit_parameter,
-                                plot_crit=True,
-                                close_window_crit=True)'''
+                        sig_params[tech]['l_parameter'] = l_values[tech]
                     except:
                         """If sigmoid fitting failed, implement linear diffusion
 
@@ -632,4 +660,8 @@ def tech_sigmoid_parameters(
                         sig_params[tech]['steepness'] = 'linear'
                         sig_params[tech]['l_parameter'] = 'linear'
 
+                        # Calculate linear slope and linear y-intercept (with two data points)
+                        sig_params[tech]['linear_slope'] = calc_m(xdata[0], xdata[1], ydata[0], ydata[1])
+                        sig_params[tech]['linear_y_intercept'] = calc_c(sig_params[tech]['linear_slope'], xdata[0], ydata[0])
+
     return dict(sig_params)
