@@ -30,12 +30,9 @@ def post_install_setup(args):
     print("... start running initialisation scripts", flush=True)
 
     path_config_file = args.config_file
-
-
     config = data_loader.read_config_file(path_config_file)
 
     local_data_path = config['PATHS']['path_local_data']
-
     base_yr = config['CONFIG']['base_yr']
 
     data = {}
@@ -82,31 +79,4 @@ def post_install_setup(args):
         data['local_paths'],
         data['lookups'])
 
-    # Input data preparation
-    print("Generate additional data", flush=True)
-
-    # Extract NISMOD population data
-    path_to_zip_file = os.path.join(local_data_path,"population-economic-smif-csv-from-nismod-db.zip")
-    path_extraction = os.path.join(local_data_path, 'scenarios', "MISTRAL_pop_gva")
-    zip_ref = zipfile.ZipFile(path_to_zip_file, 'r')
-    zip_ref.extractall(path_extraction)
-    zip_ref.close()
-
-    # Complete gva and pop data for every sector
-    data_pop = os.path.join(local_data_path, "scenarios", "MISTRAL_pop_gva", "data")
-    path_geography = os.path.join(local_data_path, "scenarios", "uk_pop_principal_2015_2050_MSOA_england.csv")
-    geography_name = "lad_uk_2016"
-
-    # All MISTRAL scenarios to prepare with correct config
-    scenarios_to_generate = ['pop-baseline16_econ-c16_fuel-c16']
-    #scenarios_to_generate = []
-
-    script_data_preparation_MISTRAL_pop_gva.run(
-        path_to_folder=data_pop,
-        path_MSOA_baseline=path_geography,
-        MSOA_calculations=False,
-        geography_name=geography_name,
-        scenarios_to_generate=scenarios_to_generate)
-
     print("... successfully finished setup")
-    return
