@@ -7,15 +7,16 @@ import copy
 import numpy as np
 import matplotlib.pyplot as plt
 from scipy import stats
-from energy_demand.plotting import plotting_program
-from energy_demand.plotting import plotting_results
+
+from energy_demand.basic import lookup_tables
+from energy_demand import enduse_func
+from energy_demand.profiles import load_profile
 from energy_demand.validation import elec_national_data
 from energy_demand.read_write import data_loader
 from energy_demand.basic import date_prop
-from energy_demand import enduse_func
-from energy_demand.profiles import load_profile
+from energy_demand.plotting import fig_load_profile_dh_multiple
+from energy_demand.plotting import basic_plot_functions
 from energy_demand.plotting import plotting_styles
-from energy_demand.basic import basic_functions
 
 def map_LAD_2011_2015(lad_data):
     """Map LAD 2015 values to LAD 2011.
@@ -34,22 +35,31 @@ def map_LAD_2011_2015(lad_data):
 
     mapped_lads.keys()
 
-    # E41000324 (City of London, Westminster) splits
-    # to E09000001 (City of London) and E09000033 (Westminster)
-    mapped_lads['E41000324'] = lad_data['E09000001'] + lad_data['E09000033']
-    del mapped_lads['E09000001']
-    del mapped_lads['E09000033']
+    try:
+        # E41000324 (City of London, Westminster) splits
+        # to E09000001 (City of London) and E09000033 (Westminster)
+        mapped_lads['E41000324'] = lad_data['E09000001'] + lad_data['E09000033']
+        del mapped_lads['E09000001']
+        del mapped_lads['E09000033']
+    except:
+        pass
 
-    # E41000052 (Cornwall, Isles of Scilly) splits
-    # to E06000052 (Cornwall) and E06000053 (Isles of Scilly) (edited)
-    mapped_lads['E41000052'] = lad_data['E06000052'] + lad_data['E06000053']
-    del mapped_lads['E06000052']
-    del mapped_lads['E06000053']
+    try:
+        # E41000052 (Cornwall, Isles of Scilly) splits
+        # to E06000052 (Cornwall) and E06000053 (Isles of Scilly) (edited)
+        mapped_lads['E41000052'] = lad_data['E06000052'] + lad_data['E06000053']
+        del mapped_lads['E06000052']
+        del mapped_lads['E06000053']
+    except:
+        pass
 
-    # missing S12000013 (Na h-Eileanan Siar)
-    # and S12000027 (Shetland Islands)
-    del mapped_lads['S12000013']
-    del mapped_lads['S12000027']
+    try:
+        # missing S12000013 (Na h-Eileanan Siar)
+        # and S12000027 (Shetland Islands)
+        del mapped_lads['S12000013']
+        del mapped_lads['S12000027']
+    except:
+        pass
 
     return mapped_lads
 
@@ -57,8 +67,6 @@ def temporal_validation(
         result_paths,
         ed_fueltype_yh,
         elec_factored_yh,
-        elec_2015_indo,
-        elec_2015_itsdo,
         plot_criteria
     ):
     """National hourly electricity data is validated with
@@ -74,8 +82,6 @@ def temporal_validation(
         Paths
     ed_fueltype_yh : array
         Fuel type specific yh energy demand
-    elec_2015_indo
-    elec_2015_itsdo
     plot_criteria : bool
         Criteria to show plots or not
     """
@@ -86,8 +92,6 @@ def temporal_validation(
     elec_national_data.compare_results(
         'validation_temporal_electricity_8760h.pdf',
         result_paths['data_results_validation'],
-        elec_2015_indo,
-        elec_2015_itsdo,
         elec_factored_yh,
         ed_fueltype_yh,
         'all_submodels',
@@ -108,8 +112,6 @@ def temporal_validation(
     elec_national_data.compare_results(
         'validation_temporal_electricity_weeks_selection.pdf',
         result_paths['data_results_validation'],
-        elec_2015_indo,
-        elec_2015_itsdo,
         elec_factored_yh,
         ed_fueltype_yh,
         'all_submodels',
@@ -120,8 +122,7 @@ def temporal_validation(
 
 def spatial_validation_lad_level(
         disaggregated_fuel,
-        lookups,
-        result_paths,
+        data_results_validation,
         paths,
         regions,
         reg_coord,
@@ -136,43 +137,26 @@ def spatial_validation_lad_level(
     fuel_elec_residential_regs_yh = {}
     fuel_elec_non_residential_regs_yh = {}
 
+    lookups =  lookup_tables.basic_lookups()
     # -------------------------------------------
     # Spatial validation
     # -------------------------------------------
-    subnational_elec = data_loader.read_national_real_elec_data(
-        paths['path_val_subnational_elec'])
-    subnational_elec_residential = data_loader.read_national_real_elec_data(
-        paths['path_val_subnational_elec_residential'])
-    subnational_elec_non_residential = data_loader.read_national_real_elec_data(
-        paths['path_val_subnational_elec_non_residential'])
-    subnational_gas = data_loader.read_national_real_gas_data(
-        paths['path_val_subnational_gas'])
-    subnational_gas_residential = data_loader.read_national_real_gas_data(
-        paths['path_val_subnational_gas_residential'])
-    subnational_gas_non_residential = data_loader.read_national_real_gas_data(
-        paths['path_val_subnational_gas_non_residential'])
-    logging.info("compare total II {}  {}".format(
-        sum(subnational_gas.values()), sum(subnational_gas_residential.values())))
+    subnational_elec = data_loader.read_lad_demands(paths['val_subnational_elec'])
+    subnational_elec_residential = data_loader.read_lad_demands(paths['val_subnational_elec_residential'])
+    subnational_elec_non_residential = data_loader.read_lad_demands(paths['val_subnational_elec_non_residential'])
+    subnational_gas = data_loader.read_lad_demands(paths['val_subnational_gas'])
+    subnational_gas_residential = data_loader.read_lad_demands(paths['val_subnational_gas_residential'])
+    subnational_gas_non_residential = data_loader.read_lad_demands(paths['val_subnational_gas_non_residential'])
+    logging.info("compare total II {}  {}".format(sum(subnational_gas.values()), sum(subnational_gas_residential.values())))
 
     # Create fueltype secific dict
     for region in regions:
-        gwh_modelled_elec = disaggregated_fuel['tot_disaggregated_regs'][region][lookups['fueltypes']['electricity']]
-        fuel_elec_regs_yh[region] = gwh_modelled_elec
-
-        gwh_modelled_elec_residential = disaggregated_fuel['tot_disaggregated_regs_residenital'][region][lookups['fueltypes']['electricity']]
-        fuel_elec_residential_regs_yh[region] = gwh_modelled_elec_residential
-
-        gwh_modelled_elec_non_residential = disaggregated_fuel['tot_disaggregated_regs_non_residential'][region][lookups['fueltypes']['electricity']]
-        fuel_elec_non_residential_regs_yh[region] = gwh_modelled_elec_non_residential
-        
-        gwh_modelled_gas = disaggregated_fuel['tot_disaggregated_regs'][region][lookups['fueltypes']['gas']]
-        fuel_gas_regs_yh[region] = gwh_modelled_gas
-
-        gwh_modelled_gas_residential = disaggregated_fuel['tot_disaggregated_regs_residenital'][region][lookups['fueltypes']['gas']]
-        fuel_gas_residential_regs_yh[region] = gwh_modelled_gas_residential
-        
-        gwh_modelled_gas_non_residential = disaggregated_fuel['tot_disaggregated_regs_non_residential'][region][lookups['fueltypes']['gas']]
-        fuel_gas_non_residential_regs_yh[region] = gwh_modelled_gas_non_residential
+        fuel_elec_regs_yh[region] = disaggregated_fuel['tot_disaggregated_regs'][region][lookups['fueltypes']['electricity']]
+        fuel_elec_residential_regs_yh[region] = disaggregated_fuel['tot_disaggregated_regs_residenital'][region][lookups['fueltypes']['electricity']]
+        fuel_elec_non_residential_regs_yh[region] = disaggregated_fuel['tot_disaggregated_regs_non_residential'][region][lookups['fueltypes']['electricity']]    
+        fuel_gas_regs_yh[region] = disaggregated_fuel['tot_disaggregated_regs'][region][lookups['fueltypes']['gas']]
+        fuel_gas_residential_regs_yh[region] = disaggregated_fuel['tot_disaggregated_regs_residenital'][region][lookups['fueltypes']['gas']]
+        fuel_gas_non_residential_regs_yh[region] = disaggregated_fuel['tot_disaggregated_regs_non_residential'][region][lookups['fueltypes']['gas']]
 
     # ----------------------------------------
     # Remap demands between 2011 and 2015 LADs
@@ -185,7 +169,6 @@ def spatial_validation_lad_level(
     subnational_gas_residential = map_LAD_2011_2015(subnational_gas_residential)
     subnational_gas_non_residential = map_LAD_2011_2015(subnational_gas_non_residential)
 
-
     fuel_elec_regs_yh = map_LAD_2011_2015(fuel_elec_regs_yh)
     fuel_elec_residential_regs_yh = map_LAD_2011_2015(fuel_elec_residential_regs_yh)
     fuel_elec_non_residential_regs_yh = map_LAD_2011_2015(fuel_elec_non_residential_regs_yh)
@@ -197,50 +180,7 @@ def spatial_validation_lad_level(
     logging.info("compare total {}  {}".format(
         sum(fuel_gas_residential_regs_yh.values()), sum(fuel_gas_regs_yh.values())))
 
-    # ---------------------
-    # Compare total sums and apply correction factor
-    # ---------------------
-    '''
-    # Total sum modelled
-    tot_sum_modelled_elec = sum(fuel_elec_regs_yh.values())
-    tot_sum_modelled_resid_elec = sum(fuel_elec_residential_regs_yh.values())
-    tot_sum_modelled_gas = sum(fuel_gas_regs_yh.values())
-
-    # Total sum real
-    tot_sum_real_elec = sum(subnational_elec.values())
-    tot_sum_real_resid_elec = sum(subnational_elec_residential.values())
-
-    logging.info("Spatial electricity validation: modelled: {}  real: {}".format(tot_sum_modelled_elec, tot_sum_real_elec))
-    logging.info("comparison real: {}  modelled: {}".format(100, (100 / tot_sum_real_elec) * tot_sum_modelled_elec))
-    tot_sum_real_gas = sum(subnational_gas.values())
-    logging.info("Spatial gas validation: modelled: {}  real: {}".format(tot_sum_modelled_gas, tot_sum_real_gas))
-    logging.info("comparison real: {}  modelled: {}".format(100, (100 / tot_sum_real_gas) * tot_sum_modelled_gas))
-    
-    # Calculate correction factor
-    correction_factor_elec = tot_sum_modelled_elec / tot_sum_real_elec
-    correction_factor_resid_elec = tot_sum_modelled_resid_elec / tot_sum_real_resid_elec
-    correction_factor_gas = tot_sum_modelled_gas/ tot_sum_real_gas
-    logging.info("-------------CORRECIOTN FATOR {}  {}".format(correction_factor_elec, correction_factor_gas))
-    
-    for reg in subnational_elec:
-        subnational_elec[reg] *= correction_factor_elec
-
-    for reg in subnational_elec_residential:
-        subnational_elec_residential[reg] *= correction_factor_resid_elec
-
-    for reg in subnational_gas:
-        subnational_gas[reg] *= correction_factor_gas
-
-    tot_sum_real_elec = sum(subnational_elec.values())
-    tot_sum_real_gas = sum(subnational_gas.values())
-    logging.info("Spatial electricity validation: modelled: {}  real: {}".format(tot_sum_modelled_elec, tot_sum_real_elec))
-    logging.info("comparison real: {}  modelled: {}".format(100, (100 / tot_sum_real_elec) * tot_sum_modelled_elec))
-    tot_sum_modelled_gas = sum(fuel_gas_regs_yh.values())
-    tot_sum_real_gas = sum(subnational_gas.values())
-    logging.info("Spatial validation: modelled: {}  real: {}".format(tot_sum_modelled_gas, tot_sum_real_gas))
-    logging.info("comparison real: {}  modelled: {}".format(100, (100 / tot_sum_real_gas) * tot_sum_modelled_gas))
-    #'''
-    # ----------------------------------------------
+    # --------------------------------------------
     # Correct REAL Values that sum is the same
     # ----------------------------------------------
     data_inputlist = [
@@ -252,7 +192,7 @@ def spatial_validation_lad_level(
         input_data=data_inputlist,
         regions=regions,
         fueltype_str='elec',
-        fig_name=os.path.join(result_paths['data_results_validation'], 'validation_multiple_elec.pdf'),
+        fig_name=os.path.join(data_results_validation, 'validation_multiple_elec.pdf'),
         label_points=False,
         plotshow=plot_crit)
 
@@ -265,73 +205,67 @@ def spatial_validation_lad_level(
         input_data=data_inputlist,
         regions=regions,
         fueltype_str='gas',
-        fig_name=os.path.join(result_paths['data_results_validation'], 'validation_multiple_gas.pdf'),
+        fig_name=os.path.join(data_results_validation, 'validation_multiple_gas.pdf'),
         label_points=False,
         plotshow=plot_crit)
 
     logging.info("... Validation of electricity")
     spatial_validation(
-        reg_coord,
         fuel_elec_regs_yh,
         subnational_elec,
         regions,
         'elec',
-        os.path.join(result_paths['data_results_validation'], 'validation_spatial_elec.pdf'),
+        os.path.join(data_results_validation, 'validation_spatial_elec.pdf'),
         label_points=True,
         plotshow=plot_crit)
 
     logging.info("... Validation of residential electricity")
     spatial_validation(
-        reg_coord,
         fuel_elec_residential_regs_yh,
         subnational_elec_residential,
         regions,
         'elec',
-        os.path.join(result_paths['data_results_validation'], 'validation_spatial_residential_elec.pdf'),
+        os.path.join(data_results_validation, 'validation_spatial_residential_elec.pdf'),
         label_points=True,
         plotshow=plot_crit)
 
     logging.info("... Validation of non-residential electricity")
     spatial_validation(
-        reg_coord,
         fuel_elec_non_residential_regs_yh,
         subnational_elec_non_residential,
         regions,
         'elec',
-        os.path.join(result_paths['data_results_validation'], 'validation_spatial_non_residential_elec.pdf'),
+        os.path.join(data_results_validation, 'validation_spatial_non_residential_elec.pdf'),
         label_points=True,
         plotshow=plot_crit)
 
     logging.info("... Validation of gas")
     spatial_validation(
-        reg_coord,
         fuel_gas_regs_yh,
         subnational_gas,
         regions,
         'gas',
-        os.path.join(result_paths['data_results_validation'], 'validation_spatial_gas.pdf'),
+        os.path.join(data_results_validation, 'validation_spatial_gas.pdf'),
         label_points=True,
         plotshow=plot_crit)
 
     logging.info("... Validation of residential gas")
     spatial_validation(
-        reg_coord,
         fuel_gas_residential_regs_yh,
         subnational_gas_residential,
         regions,
         'gas',
-        os.path.join(result_paths['data_results_validation'], 'validation_spatial_residential_gas.pdf'),
+        os.path.join(data_results_validation, 'validation_spatial_residential_gas.pdf'),
         label_points=True,
         plotshow=plot_crit)
 
     logging.info("... Validation of non residential gas")
     spatial_validation(
-        reg_coord,
         fuel_gas_non_residential_regs_yh,
         subnational_gas_non_residential,
         regions,
         'gas',
-        os.path.join(result_paths['data_results_validation'], 'validation_spatial_non_residential_gas.pdf'),
+        os.path.join(data_results_validation, 'validation_spatial_non_residential_gas.pdf'),
         label_points=True,
         plotshow=plot_crit)
 
@@ -365,12 +299,12 @@ def temporal_validation_msoa_lad(
     # -------------------------------------------
 
     # LAD level
-    subnational_elec_lad = data_loader.read_national_real_elec_data(
-        paths['path_val_subnational_elec'])
+    subnational_elec_lad = data_loader.read_lad_demands(
+        paths['val_subnational_elec'])
 
     # MSOA level
     subnational_elec_msoa = data_loader.read_elec_data_msoa(
-        paths['path_val_subnational_msoa_elec'])
+        paths['val_subnational_msoa_elec'])
 
     # Create fueltype secific dict
     fuel_elec_regs_yh = {}
@@ -391,7 +325,6 @@ def temporal_validation_msoa_lad(
     fuel_elec_regs_yh = map_LAD_2011_2015(fuel_elec_regs_yh)
 
     spatial_validation(
-        reg_coord,
         fuel_elec_regs_yh,
         subnational_elec,
         regions,
@@ -402,21 +335,17 @@ def temporal_validation_msoa_lad(
 
     return
 
-def temporal_validation_lad(
+def spatio_temporal_val(
         ed_fueltype_national_yh,
         ed_fueltype_regs_yh,
-        fueltypes,
         result_paths,
         paths,
         regions,
-        reg_coord,
         seasons,
         model_yeardays_daytype,
         plot_crit
     ):
-    """Validate national hourly demand for yearls fuel
-    for all LADs. Test how the national disaggregation
-    works.
+    """Validate spatial and temporal energy demands
 
     Info
     -----
@@ -425,25 +354,24 @@ def temporal_validation_lad(
     """
     logging.info("... temporal validation")
 
+    fueltypes =  lookup_tables.basic_lookups()['fueltypes']
     # -------------------------------------------
     # Spatial validation after calculations
     # -------------------------------------------
-    subnational_elec = data_loader.read_national_real_elec_data(
-        paths['path_val_subnational_elec'])
-    subnational_gas = data_loader.read_national_real_gas_data(
-        paths['path_val_subnational_gas'])
+    subnational_elec = data_loader.read_lad_demands(
+        paths['val_subnational_elec'])
+    subnational_gas = data_loader.read_lad_demands(
+        paths['val_subnational_gas'])
 
     # Create fueltype secific dict
     fuel_elec_regs_yh = {}
     for region_array_nr, region in enumerate(regions):
-        gwh_modelled = np.sum(ed_fueltype_regs_yh[fueltypes['electricity']][region_array_nr])
-        fuel_elec_regs_yh[region] = gwh_modelled
+        fuel_elec_regs_yh[region] = np.sum(ed_fueltype_regs_yh[fueltypes['electricity']][region_array_nr])
 
     # Create fueltype secific dict
     fuel_gas_regs_yh = {}
     for region_array_nr, region in enumerate(regions):
-        gwh_modelled = np.sum(ed_fueltype_regs_yh[fueltypes['gas']][region_array_nr])
-        fuel_gas_regs_yh[region] = gwh_modelled
+        fuel_gas_regs_yh[region] = np.sum(ed_fueltype_regs_yh[fueltypes['gas']][region_array_nr])
 
     # ----------------------------------------
     # Remap demands between 2011 and 2015 LADs
@@ -454,22 +382,20 @@ def temporal_validation_lad(
     fuel_gas_regs_yh = map_LAD_2011_2015(fuel_gas_regs_yh)
 
     spatial_validation(
-        reg_coord,
         fuel_elec_regs_yh,
         subnational_elec,
         regions,
         'elec',
-        os.path.join(result_paths['data_results_validation'], 'validation_spatial_elec_post_calcualtion.pdf'),
+        fig_name=os.path.join(result_paths['data_results_validation'], 'validation_spatial_elec_post_calcualtion.pdf'),
         label_points=False,
         plotshow=plot_crit)
 
     spatial_validation(
-        reg_coord,
         fuel_gas_regs_yh,
         subnational_gas,
         regions,
         'gas',
-        os.path.join(result_paths['data_results_validation'], 'validation_spatial_gas_post_calcualtion.pdf'),
+        fig_name=os.path.join(result_paths['data_results_validation'], 'validation_spatial_gas_post_calcualtion.pdf'),
         label_points=False,
         plotshow=plot_crit)
 
@@ -478,16 +404,10 @@ def temporal_validation_lad(
     # -------------------------------------------
     # Read validation data
     elec_2015_indo, elec_2015_itsdo = elec_national_data.read_raw_elec_2015(
-        paths['path_val_nat_elec_data'])
-
-    #print(np.max(elec_2015_indo))
-    #print(np.max(elec_2015_itsdo))
-    #print(np.sum(elec_2015_indo))
-    #print(np.sum(elec_2015_itsdo))
+        paths['val_nat_elec_data'])
 
     f_diff_elec = np.sum(ed_fueltype_national_yh[fueltypes['electricity']]) / np.sum(elec_2015_indo)
-    logging.info(
-        "... ed diff modellend and real [p] %s: ", (1 - f_diff_elec) * 100)
+    logging.info("... ed diff modellend and real [p] %s: ", (1 - f_diff_elec) * 100)
 
     elec_factored_yh = f_diff_elec * elec_2015_indo
 
@@ -495,8 +415,6 @@ def temporal_validation_lad(
         result_paths,
         ed_fueltype_national_yh[fueltypes['electricity']],
         elec_factored_yh,
-        elec_2015_indo,
-        elec_2015_itsdo,
         plot_crit)
 
     # ---------------------------------------------------
@@ -515,7 +433,7 @@ def temporal_validation_lad(
         model_yeardays_daytype)
 
     # Plot average daily loads
-    plotting_results.plot_load_profile_dh_multiple(
+    fig_load_profile_dh_multiple.run(
         path_fig_folder=result_paths['data_results_validation'],
         path_plot_fig=os.path.join(
             result_paths['data_results_validation'],
@@ -545,9 +463,11 @@ def temporal_validation_lad(
 
     # Peak across all fueltypes WARNING: Fueltype specific
     peak_day_all_fueltypes = enduse_func.get_peak_day_all_fueltypes(ed_fueltype_national_yh)
+    logging.info("Peak day 'peak_day_all_fueltypes': " + str(peak_day_all_fueltypes))
 
     fueltype = fueltypes['electricity']
     peak_day_electricity, _ = enduse_func.get_peak_day_single_fueltype(ed_fueltype_national_yh[fueltype])
+    logging.info("Peak day 'peak_day_electricity': " + str(peak_day_electricity))
 
     elec_national_data.compare_peak(
         "validation_peak_elec_day_all_fueltypes.pdf",
@@ -568,7 +488,7 @@ def temporal_validation_lad(
     elec_national_data.compare_peak(
         "validation_elec_peak_day_{}.pdf".format(peak_day),
         result_paths['data_results_validation'],
-        elec_2015_indo[peak_day],
+        elec_factored_yh[peak_day],
         ed_fueltype_national_yh[fueltypes['electricity']][peak_day],
         peak_day)
 
@@ -576,10 +496,21 @@ def temporal_validation_lad(
     elec_national_data.compare_peak(
         "validation_elec_peak_day_{}.pdf".format(peak_day),
         result_paths['data_results_validation'],
-        elec_2015_indo[peak_day],
+        elec_factored_yh[peak_day],
         ed_fueltype_national_yh[fueltypes['electricity']][peak_day],
         peak_day)
 
+    peak_day_real_electricity, _ = enduse_func.get_peak_day_single_fueltype(elec_2015_indo)
+    logging.info("Peak day 'peak_day_electricity': " + str(peak_day_real_electricity))
+
+    #raise Exception
+    elec_national_data.compare_peak(
+        "validation_elec_peak_day_{}.pdf".format(peak_day_real_electricity),
+        result_paths['data_results_validation'],
+        elec_factored_yh[peak_day],
+        ed_fueltype_national_yh[fueltypes['electricity']][peak_day_real_electricity],
+        peak_day_real_electricity)
+
     # ---------------------------------------------------
     # Validate boxplots for every hour (temporal validation)
     # ---------------------------------------------------
@@ -592,7 +523,6 @@ def temporal_validation_lad(
     return
 
 def spatial_validation(
-        reg_coord,
         subnational_modelled,
         subnational_real,
         regions,
@@ -621,40 +551,33 @@ def spatial_validation(
     result_dict = {}
     result_dict['real_demand'] = {}
     result_dict['modelled_demand'] = {}
-
-    # -------------------------------------------
-    # Match ECUK sub-regional demand with geocode
-    # -------------------------------------------
-    for region in regions:
-        for reg_geocode in reg_coord:
-            if reg_geocode == region:
-                try:
-                    # Test wheter data is provided for LAD or owtherwise ignore
-                    if subnational_real[reg_geocode] == 0:
-                        pass
-                    else:
-                        # --Sub Regional Electricity demand (as GWh)
-                        result_dict['real_demand'][reg_geocode] = subnational_real[reg_geocode]
-                        result_dict['modelled_demand'][reg_geocode] = subnational_modelled[reg_geocode]
-
-                except KeyError:
-                    logging.debug(
-                        "Sub-national spatial validation: No fuel for region %s", reg_geocode)
-
-    # --------------------
-    # Calculate statistics
-    # --------------------
     diff_real_modelled_p = []
     diff_real_modelled_abs = []
 
-    for reg_geocode in regions:
+    # -------------------------------------------
+    # Match ECUK sub-regional demand with geocode and calculate statistics
+    # -------------------------------------------
+    for region in regions:
         try:
-            real = result_dict['real_demand'][reg_geocode]
-            modelled = result_dict['modelled_demand'][reg_geocode]
-            diff_real_modelled_p.append(abs(100 - ((100 / real) * modelled)))
-            diff_real_modelled_abs.append(real - modelled)
+            if subnational_real[region] == 0:
+                pass
+            else:
+                try:
+                    real = subnational_real[region]
+                    modelled = subnational_modelled[region]
+
+                    # --Sub Regional Electricity demand (as GWh)
+                    result_dict['real_demand'][region] = real
+                    result_dict['modelled_demand'][region] = modelled
+
+                    diff_real_modelled_p.append(abs(100 - ((100 / real) * modelled)))
+                    diff_real_modelled_abs.append(real - modelled)
+                except KeyError:
+                    pass #not both data for reald and modelled
+
         except KeyError:
-            pass
+            logging.debug(
+                "Sub-national spatial validation: No fuel for region %s", region)
 
     # Calculate the average deviation between reald and modelled
     av_deviation_real_modelled = np.average(diff_real_modelled_p)
@@ -674,8 +597,7 @@ def spatial_validation(
     # -------------------------------------
     # Plot
     # -------------------------------------
-    fig = plt.figure(
-        figsize=plotting_program.cm2inch(9, 8)) #width, height (9, 8)
+    fig = plt.figure(figsize=basic_plot_functions.cm2inch(9, 8))
 
     ax = fig.add_subplot(1, 1, 1)
 
@@ -686,13 +608,10 @@ def spatial_validation(
 
     labels = []
     for sorted_region in sorted_dict_real:
-
         geocode_lad = sorted_region[0]
 
-        y_real_demand.append(
-            result_dict['real_demand'][geocode_lad])
-        y_modelled_demand.append(
-            result_dict['modelled_demand'][geocode_lad])
+        y_real_demand.append(result_dict['real_demand'][geocode_lad])
+        y_modelled_demand.append(result_dict['modelled_demand'][geocode_lad])
 
         logging.debug(
             "validation %s LAD %s: real: %s modelled: %s  modelled percentage: %s (%sp diff)",
@@ -703,7 +622,6 @@ def spatial_validation(
             round(100 / result_dict['real_demand'][geocode_lad] * result_dict['modelled_demand'][geocode_lad], 4),
             round(100 - (100 / result_dict['real_demand'][geocode_lad] * result_dict['modelled_demand'][geocode_lad]), 4))
 
-        # Labels
         labels.append(geocode_lad)
 
     # Calculate r_squared
@@ -751,7 +669,6 @@ def spatial_validation(
         color='black',
         label='model')
 
-    # Limit
     plt.ylim(ymin=0)
 
     # -----------
@@ -759,7 +676,6 @@ def spatial_validation(
     # -----------
     if label_points:
         for pos, txt in enumerate(labels):
-
             ax.text(
                 x_values[pos],
                 y_modelled_demand[pos],
@@ -838,7 +754,7 @@ def spatial_validation_multiple(
     # Plot
     # -------------------------------------
     fig = plt.figure(
-        figsize=plotting_program.cm2inch(9, 8)) #width, height
+        figsize=basic_plot_functions.cm2inch(9, 8)) #width, height
 
     ax = fig.add_subplot(1, 1, 1)
 
@@ -875,13 +791,28 @@ def spatial_validation_multiple(
         diff_real_modelled_p = []
         diff_real_modelled_abs = []
 
-        for reg_geocode in regions:
+        y_real_demand = []
+        y_modelled_demand = []
+
+        # -----------------
+        # Sort results according to size
+        # -----------------
+        sorted_dict_real = sorted(
+            result_dict['real_demand'].items(),
+            key=operator.itemgetter(1))
+    
+        #for reg_geocode in regions:
+        for reg_geocode, _ in sorted_dict_real:
+            # Test if real and modelled data are both available
             try:
                 real = result_dict['real_demand'][reg_geocode]
                 modelled = result_dict['modelled_demand'][reg_geocode]
-                #diff_real_modelled_p.append(100 - (100 / real) * modelled)
+
                 diff_real_modelled_p.append(abs(100 - ((100 / real) * modelled))) # Average abs deviation
                 diff_real_modelled_abs.append(real - modelled)
+
+                y_real_demand.append(real)
+                y_modelled_demand.append(modelled)
             except KeyError:
                 pass
 
@@ -893,43 +824,25 @@ def spatial_validation_multiple(
         std_dev_p = np.std(diff_real_modelled_p)        # Given as percent
         std_dev_abs = np.std(diff_real_modelled_abs)    # Given as energy unit
 
-        rmse = basic_functions.rmse(
-            np.array(list(result_dict['real_demand'].values())),
-            np.array(list(result_dict['modelled_demand'].values())))
 
-        # -----------------
-        # Sort results according to size
-        # -----------------
-        sorted_dict_real = sorted(
-            result_dict['real_demand'].items(),
-            key=operator.itemgetter(1))
 
-        x_values = np.arange(0, len(sorted_dict_real), 1)
-
-        y_real_demand = []
-        y_modelled_demand = []
+        x_values = np.arange(0, len(y_real_demand), 1)
 
         labels = []
         for sorted_region in sorted_dict_real:
+            if sorted_region in y_real_demand:
+                geocode_lad = sorted_region[0]
 
-            geocode_lad = sorted_region[0]
+                logging.debug(
+                    "validation %s LAD %s: real: %s modelled: %s  modelled percentage: %s (%sp diff)",
+                    fueltype_str,
+                    geocode_lad,
+                    round(result_dict['real_demand'][geocode_lad], 4),
+                    round(result_dict['modelled_demand'][geocode_lad], 4),
+                    round(100 / result_dict['real_demand'][geocode_lad] * result_dict['modelled_demand'][geocode_lad], 4),
+                    round(100 - (100 / result_dict['real_demand'][geocode_lad] * result_dict['modelled_demand'][geocode_lad]), 4))
 
-            y_real_demand.append(
-                result_dict['real_demand'][geocode_lad])
-            y_modelled_demand.append(
-                result_dict['modelled_demand'][geocode_lad])
-
-            logging.debug(
-                "validation %s LAD %s: real: %s modelled: %s  modelled percentage: %s (%sp diff)",
-                fueltype_str,
-                geocode_lad,
-                round(result_dict['real_demand'][geocode_lad], 4),
-                round(result_dict['modelled_demand'][geocode_lad], 4),
-                round(100 / result_dict['real_demand'][geocode_lad] * result_dict['modelled_demand'][geocode_lad], 4),
-                round(100 - (100 / result_dict['real_demand'][geocode_lad] * result_dict['modelled_demand'][geocode_lad]), 4))
-
-            # Labels
-            labels.append(geocode_lad)
+                labels.append(geocode_lad)
 
         # Calculate r_squared
         _slope, _intercept, r_value, _p_value, _std_err = stats.linregress(
@@ -1012,8 +925,6 @@ def spatial_validation_multiple(
 
     plt.xlabel("UK regions (excluding northern ireland)")
     plt.ylabel("{} [GWh]".format(fueltype_str))
-
-    # Limit
     plt.ylim(ymin=0)
 
     # --------
